.. _API:

API
---

Use these tools to interact with django-cachalot, especially if you face
:ref:`raw queries limits <Raw SQL queries>` or if you need to create a cache key from the
last table invalidation timestamp.

.. automodule:: cachalot.api
   :members:
